@@ -39,7 +39,11 @@ def parse_config():
         os.path.join(os.path.expanduser("~"), ".sd-upload-config.yml"),
         os.path.join(os.path.expanduser("~"), ".sd-upload-config.yaml"),
         "sd-upload-config.yml",
-        "sd-upload-config.yaml"
+        "sd-upload-config.yaml",
+         "/opt/robin/config/sd-upload",
+         "/opt/robin/config/sd-upload",
+        "/opt/robin/config/sd-upload/sd-upload-config.yml",
+        "/opt/robin/config/sd-upload/sd-upload-config.yaml"
     ]
 
     config = None
@@ -53,11 +57,11 @@ def parse_config():
                 file = cfg_file
                 break
         else:
-            admin_interface = "https://software-api-admin.robinradar.systems"
-            doc_pages = "https://robinradar.atlassian.net/wiki/spaces/DEV/pages/284033095/Software+Deployment+API"
             print(f"Config file not found in {cfg_file} directory.")
             print(f"Checking next directory...")
     if not config:
+        admin_interface = "https://software-api-admin.robinradar.systems"
+        doc_pages = "https://robinradar.atlassian.net/wiki/spaces/DEV/pages/284033095/Software+Deployment+API"
         print(f"Error: no config file found.")
         print(f"Please browse to {admin_interface} to create a config file.")
         print(f"Please browse to {doc_pages} to learn how to create a config file.")
